using BinaryProvider # requires BinaryProvider 0.3.0 or later

# Parse some basic command-line arguments
const verbose = "--verbose" in ARGS
const prefix = Prefix(get([a for a in ARGS if a != "--verbose"], 1, joinpath(@__DIR__, "usr")))
products = [
    ExecutableProduct(prefix, "xc-threshold", :xcthreshold),
    LibraryProduct(prefix, ["libxc"], :libxc),
    ExecutableProduct(prefix, "xc-info", :xcinfo),
]

# Download binaries from hosted location
bin_prefix = "https://github.com/unkcpz/LibxcBuilder/releases/download/v0.1.2"

# Listing of files generated by BinaryBuilder:
download_info = Dict(
    Linux(:i686, libc=:glibc) => ("$bin_prefix/LibxcBuilder.v4.3.4.i686-linux-gnu.tar.gz", "dc4b6907082461a8e9207ed35cff81e41f0965c23b7ddc1b2972283c2e8ea39b"),
    MacOS(:x86_64) => ("$bin_prefix/LibxcBuilder.v4.3.4.x86_64-apple-darwin14.tar.gz", "5460c3ca9633ee62b9c07f5fddce73db43cbca905fe930a8f538833131baef8c"),
    Linux(:x86_64, libc=:glibc) => ("$bin_prefix/LibxcBuilder.v4.3.4.x86_64-linux-gnu.tar.gz", "e88fe873818ed7218045ad3bb40ee1e8386b03c6986ccde74b1700500b1a0cc6"),
)

# Install unsatisfied or updated dependencies:
unsatisfied = any(!satisfied(p; verbose=verbose) for p in products)
dl_info = choose_download(download_info, platform_key_abi())
if dl_info === nothing && unsatisfied
    # If we don't have a compatible .tar.gz to download, complain.
    # Alternatively, you could attempt to install from a separate provider,
    # build from source or something even more ambitious here.
    error("Your platform (\"$(Sys.MACHINE)\", parsed as \"$(triplet(platform_key_abi()))\") is not supported by this package!")
end

# If we have a download, and we are unsatisfied (or the version we're
# trying to install is not itself installed) then load it up!
if unsatisfied || !isinstalled(dl_info...; prefix=prefix)
    # Download and install binaries
    install(dl_info...; prefix=prefix, force=true, verbose=verbose)
end

# Write out a deps.jl file that will contain mappings for our products
write_deps_file(joinpath(@__DIR__, "deps.jl"), products, verbose=verbose)
